ObjectCollisionMatrix class

Records what objects are colliding with each other

Constructors

ObjectCollisionMatrix(Map<String, bool>? matrix)

Properties

hashCode → int
The hash code for this object.
no setterinherited
matrix ↔ Map<String, bool>
The matrix storage.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(Body bi, Body bj) → bool
get
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Empty the matrix
set(Body bi, Body bj, bool value) → void
set
setNumObjects(int n) → void
Set max number of objects
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited