RayOptions class

RayOptions

Constructors

RayOptions({Vector3? from, Vector3? to, RaycastCallback? callback, RayMode? mode, bool? checkCollisionResponse, int? collisionFilterGroup, int? collisionFilterMask, RaycastResult? result, bool? skipBackfaces})

Properties

callback ↔ RaycastCallback?
getter/setter pair
checkCollisionResponse ↔ bool?
getter/setter pair
collisionFilterGroup ↔ int?
getter/setter pair
collisionFilterMask ↔ int?
getter/setter pair
from ↔ Vector3?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ RayMode?
getter/setter pair
result ↔ RaycastResult?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipBackfaces ↔ bool?
getter/setter pair
to ↔ Vector3?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited