SplitSolverNode class

Constructors

SplitSolverNode({Body? body, List<SplitSolverNode>? children, List<Equation>? eqs, bool visited = false})

Properties

body ↔ Body?
getter/setter pair
children ↔ List<SplitSolverNode>
latefinal
eqs ↔ List<Equation>
latefinal
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visited ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited