ShapeContactEvent class

Inheritance

Constructors

ShapeContactEvent({required dynamic type, Body? bodyA, Body? bodyB, Shape? shapeA, Shape? shapeB})

Properties

bodyA ↔ Body?
getter/setter pair
bodyB ↔ Body?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeA ↔ Shape?
getter/setter pair
shapeB ↔ Shape?
getter/setter pair
target ↔ EventTarget?
getter/setter pairinherited
type → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited