Octree class

Inheritance

Constructors

Octree({AABB? aabb, int maxDepth = 8})
@param aabb The total AABB of the tree

Properties

aabb ↔ AABB
Boundary of this node
getter/setter pairinherited
children ↔ List<OctreeNode>
Children to this node
getter/setter pairinherited
data ↔ List<int>
Contained data at the current node level
getter/setter pairinherited
halfDiagonal → Vector3
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
maxDepth ↔ int?
getter/setter pairinherited
root ↔ OctreeNode?
The root node
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tmpAABB → AABB
finalinherited

Methods

aabbQuery(AABB aabb, List<int> result) → List<int>
Get all data, potentially within an AABB @return The "result" object
inherited
insert(AABB aabb, int elementData, [int level = 0]) → bool
Insert data into this node @return True if successful, otherwise false
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rayQuery(Ray ray, Transform treeTransform, List<int> result) → List<int>
Get all data, potentially intersected by a ray. @return The "result" object
inherited
removeEmptyNodes() → void
inherited
reset() → void
reset
inherited
subdivide() → void
Create 8 equally sized children nodes and put them in the children array
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited