OctreeNode class

Implementers

Constructors

OctreeNode({OctreeNode? root, AABB? aabb})

Properties

aabb ↔ AABB
Boundary of this node
getter/setter pair
children ↔ List<OctreeNode>
Children to this node
getter/setter pair
data ↔ List<int>
Contained data at the current node level
getter/setter pair
halfDiagonal → Vector3
final
hashCode → int
The hash code for this object.
no setterinherited
maxDepth ↔ int?
getter/setter pair
root ↔ OctreeNode?
The root node
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tmpAABB → AABB
final

Methods

aabbQuery(AABB aabb, List<int> result) → List<int>
Get all data, potentially within an AABB @return The "result" object
insert(AABB aabb, int elementData, [int level = 0]) → bool
Insert data into this node @return True if successful, otherwise false
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rayQuery(Ray ray, Transform treeTransform, List<int> result) → List<int>
Get all data, potentially intersected by a ray. @return The "result" object
removeEmptyNodes() → void
reset() → void
reset
subdivide() → void
Create 8 equally sized children nodes and put them in the children array
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited